@@ -3,7 +3,6 @@
 
 #include <gnome.h>
 #include <sys/types.h>
-#include <linux/cdrom.h>
 
 #include "linux-cdrom.h"
 #include "prefs.h"
@@ -17,6 +16,18 @@ void setup_colors(void);
 void setup_fonts(void);
 void setup_popup_menu(GtkWidget *w, cd_struct *data);
 void edit_window(GtkWidget *widget, gpointer data);
+void cddb_status_dialog(GtkWidget *widget, gpointer data);
+void update_editor(void);
+
+GnomeClient *new_client(void);
+void session_die (gpointer client_data);
+int save_state (GnomeClient        *client,
+		       gint                phase,
+		       GnomeRestartStyle   save_style,
+		       gint                shutdown,
+		       GnomeInteractStyle  interact_style,
+		       gint                fast,
+		       gpointer            client_data);
 
 extern int titlelabel_f;
 extern cd_struct cd;
@@ -24,5 +35,6 @@ extern tcd_prefs prefs;
 extern GtkTooltips *tooltips;
 extern GtkAccelGroup *accel;
 extern GList *keys;
+extern GtkWidget *window;
 
 #endif
